

// This macro is used to produce a few tables of numbers from
// various trees with various cuts. The tables are produced in
// such a way that they can be cut and pasted into a table in
// TeX if the single argument to "stats_table" is passed as "true".
//
// This was run in the following way and the TeX tables pasted
// into GlueX-doc-1710.
//
//  root -l -b -q "stats_table.C(true)" > stats_table.txt
//


void TeXize(string &str);


void stats_table(bool print_TeX=false)
{
	// This doesn't actually make a plot. It just spits out some stats
	
	TFile *f = new TFile("pip.root");
	TTree *reconPhoton_pip = (TTree*)gROOT->FindObject("reconPhoton");
	TTree *event_pip = (TTree*)gROOT->FindObject("event");

	TFile *f = new TFile("photon.root");
	TTree *reconPhoton_photon = (TTree*)gROOT->FindObject("reconPhoton");
	TTree *event_photon = (TTree*)gROOT->FindObject("event");
	
	double tot_pip = event_pip->GetEntries();
	double tot_photon = event_photon->GetEntries();

	double tot_pip_secondaries = reconPhoton_pip->GetEntries("idist_to_thrown>0");
	double tot_photon_secondaries = reconPhoton_photon->GetEntries("idist_to_thrown>0");
	
	map<string,double> pip;
	pip["Total number of events"] = event_pip->GetEntries();
	pip["Number events with exactly 1 reconstructed photon"] = event_pip->GetEntries("Nrecon==1");
	pip["Number gen. parts w/ R>=60cm             "] = event_pip->GetEntries("sqrt(x*x+y*y)>=60.0");
	pip["Number gen. parts w/ R <60cm             "] = event_pip->GetEntries("sqrt(x*x+y*y)<60.0");
	pip["Number gen. parts w/ R>=60cm && Nrecon==1"] = event_pip->GetEntries("sqrt(x*x+y*y)>=60.0 && Nrecon==1");
	pip["Number gen. parts w/ R <60cm && Nrecon==1"] = event_pip->GetEntries("sqrt(x*x+y*y)<60.0 && Nrecon==1");

	map<string,double> pip_secondaries;
	pip_secondaries["Total number of secondaries"] = reconPhoton_pip->GetEntries("idist_to_thrown>0");
	pip_secondaries["Neutron induced secondaries"] = reconPhoton_pip->GetEntries("ptype_closest==13 && idist_to_thrown>0");
	pip_secondaries["Hadron (pi+, proton,...) induced secondaries"] = reconPhoton_pip->GetEntries("ptype_closest>=7 && idist_to_thrown>0");
	pip_secondaries["Lepton(e+,e-,gamma) induced secondaries"] = reconPhoton_pip->GetEntries("ptype_closest<=6 && idist_to_thrown>0");
	pip_secondaries["Secondaries by particles from outside BCAL"] = reconPhoton_pip->GetEntries("R.pos_origin.Perp()>90.0 && idist_to_thrown>0");
	pip_secondaries["Secondaries by particles from CDC"] = reconPhoton_pip->GetEntries("R.pos_origin.Perp()>=10.0 && R.pos_origin.Perp()<=56.5 && R.pos_origin.Z()<(17.0+150.0) && R.pos_origin.Z()>17.0 &&idist_to_thrown>0");
	pip_secondaries["Secondaries by particles from FDC"] = reconPhoton_pip->GetEntries("R.pos_origin.Perp()>=0.0 && R.pos_origin.Perp()<=62.0 && R.pos_origin.Z()<400.0 && R.pos_origin.Z()>169.0 &&idist_to_thrown>0");
	pip_secondaries["Secondaries by particles from start counter"] = reconPhoton_pip->GetEntries("R.pos_origin.Perp()>=6.9 && R.pos_origin.Perp()<=9.0 && R.pos_origin.Z()<(38.75+60.0) && R.pos_origin.Z()>38.75 &&idist_to_thrown>0");
	
	map<string,double> photon;
	photon["Total number of events"] = event_photon->GetEntries();
	photon["Number events with exactly 1 reconstructed photon"] = event_photon->GetEntries("Nrecon==1");
	photon["Number gen. parts w/ R>=60cm             "] = event_photon->GetEntries("sqrt(x*x+y*y)>=60.0");
	photon["Number gen. parts w/ R <60cm             "] = event_photon->GetEntries("sqrt(x*x+y*y)<60.0");
	photon["Number gen. parts w/ R>=60cm && Nrecon==1"] = event_photon->GetEntries("sqrt(x*x+y*y)>=60.0 && Nrecon==1");
	photon["Number gen. parts w/ R <60cm && Nrecon==1"] = event_photon->GetEntries("sqrt(x*x+y*y)<60.0 && Nrecon==1");

	map<string,double> photon_secondaries;
	photon_secondaries["Total number of secondaries"] = reconPhoton_photon->GetEntries("idist_to_thrown>0");
	photon_secondaries["Neutron induced secondaries"] = reconPhoton_photon->GetEntries("ptype_closest==13 && idist_to_thrown>0");
	photon_secondaries["Hadron (pi+, proton,...) induced secondaries"] = reconPhoton_photon->GetEntries("ptype_closest>=7 && idist_to_thrown>0");
	photon_secondaries["Lepton(e+,e-,gamma) induced secondaries"] = reconPhoton_photon->GetEntries("ptype_closest<=6 && idist_to_thrown>0");
	photon_secondaries["Secondaries by particles from outside BCAL"] = reconPhoton_photon->GetEntries("R.pos_origin.Perp()>90.0 && idist_to_thrown>0");
	photon_secondaries["Secondaries by particles from CDC"] = reconPhoton_photon->GetEntries("R.pos_origin.Perp()>=10.0 && R.pos_origin.Perp()<=56.5 && R.pos_origin.Z()<(17.0+150.0) && R.pos_origin.Z()>17.0 &&idist_to_thrown>0");
	photon_secondaries["Secondaries by particles from FDC"] = reconPhoton_photon->GetEntries("R.pos_origin.Perp()>=0.0 && R.pos_origin.Perp()<=62.0 && R.pos_origin.Z()<400.0 && R.pos_origin.Z()>169.0 &&idist_to_thrown>0");
	photon_secondaries["Secondaries by particles from start counter"] = reconPhoton_photon->GetEntries("R.pos_origin.Perp()>=6.9 && R.pos_origin.Perp()<=9.0 && R.pos_origin.Z()<(38.75+60.0) && R.pos_origin.Z()>38.75 &&idist_to_thrown>0");
	
	
	// Print pi+ table
	cout<<endl;
	cout<<"pi+"<<endl;
	cout<<"--------------------------------"<<endl;
	map<string,double>::iterator iter;
	int max_width = 1;
	for(iter=pip.begin(); iter!=pip.end(); iter++){
		int width = (iter->first).length();
		if(max_width<width)max_width = width;
	}
	for(iter=pip_secondaries.begin(); iter!=pip_secondaries.end(); iter++){
		int width = (iter->first).length();
		if(max_width<width)max_width = width;
	}
	for(iter=pip.begin(); iter!=pip.end(); iter++){
		string lab = iter->first;
		double val = iter->second;
		char tmp[256];
		sprintf(tmp, "%2.1f", 100.0*val/tot_pip);
		string percent(tmp);
	
		sprintf(tmp, "%d", val);
		string valstr(tmp);
		
		string lab_space(max_width - lab.length(), ' ');		
		string val_space((int)log10(tot_pip)+2 - valstr.length(), ' ');		
		string percent_space(5 - percent.length(), ' ');		

		cout<<lab_space<<lab<<": "
		    <<val_space<<valstr
			 <<" ("<<percent_space<<percent<<"%)"<<endl;
	}
	cout<<endl;
	cout<<" - percentages below are of reconstructed clusters thought to be secondaries -"<<endl;
	for(iter=pip_secondaries.begin(); iter!=pip_secondaries.end(); iter++){
		string lab = iter->first;
		double val = iter->second;
		char tmp[256];
		sprintf(tmp, "%2.1f", 100.0*val/tot_pip_secondaries);
		string percent(tmp);
	
		sprintf(tmp, "%d", val);
		string valstr(tmp);
		
		string lab_space(max_width - lab.length(), ' ');		
		string val_space((int)log10(tot_pip)+2 - valstr.length(), ' ');		
		string percent_space(5 - percent.length(), ' ');		

		cout<<lab_space<<lab<<": "
		    <<val_space<<val
			 <<" ("<<percent_space<<percent<<"%)"<<endl;
	}
	

	
	// Print photon table
	cout<<endl;
	cout<<"photon"<<endl;
	cout<<"--------------------------------"<<endl;
	map<string,double>::iterator iter;
	int max_width = 1;
	for(iter=photon.begin(); iter!=photon.end(); iter++){
		int width = (iter->first).length();
		if(max_width<width)max_width = width;
	}
	for(iter=photon_secondaries.begin(); iter!=photon_secondaries.end(); iter++){
		int width = (iter->first).length();
		if(max_width<width)max_width = width;
	}
	for(iter=photon.begin(); iter!=photon.end(); iter++){
		string lab = iter->first;
		double val = iter->second;
		char tmp[256];
		sprintf(tmp, "%2.1f", 100.0*val/tot_photon);
		string percent(tmp);
	
		sprintf(tmp, "%d", val);
		string valstr(tmp);
		
		string lab_space(max_width - lab.length(), ' ');		
		string val_space((int)log10(tot_photon)+2 - valstr.length(), ' ');		
		string percent_space(5 - percent.length(), ' ');		

		cout<<lab_space<<lab<<": "
		    <<val_space<<valstr
			 <<" ("<<percent_space<<percent<<"%)"<<endl;
	}
	cout<<endl;
	cout<<" - percentages below are of reconstructed clusters thought to be secondaries -"<<endl;
	for(iter=photon_secondaries.begin(); iter!=photon_secondaries.end(); iter++){
		string lab = iter->first;
		double val = iter->second;
		char tmp[256];
		sprintf(tmp, "%2.1f", 100.0*val/tot_photon_secondaries);
		string percent(tmp);
	
		sprintf(tmp, "%d", val);
		string valstr(tmp);
		
		string lab_space(max_width - lab.length(), ' ');		
		string val_space((int)log10(tot_photon)+2 - valstr.length(), ' ');		
		string percent_space(5 - percent.length(), ' ');		

		cout<<lab_space<<lab<<": "
		    <<val_space<<val
			 <<" ("<<percent_space<<percent<<"%)"<<endl;
	}
	
	if(!print_TeX)return;
	
	//-------- Print out TeX formatted data --------------
	cout<<endl<<endl<<endl;
	cout<<"TeX formatted "<<endl;
	cout<<"--------------------------------"<<endl;
	cout<<"\\hline"<<endl;
	for(iter=pip.begin(); iter!=pip.end(); iter++){
		string lab = iter->first;
		double val = iter->second;
		
		// convert label to TeX
		TeXize(lab);
		
		char tmp[256];
		sprintf(tmp, "%2.1f", 100.0*val/tot_pip);
		string percent(tmp);
	
		sprintf(tmp, "%d", val);
		string valstr(tmp);
		
		cout<<lab<<" & "
		    <<valstr<<" & "
			 <<percent<<"\\\% \\\\"
			 <<endl;
	}
	cout<<"\\hline"<<endl;
	
	cout<<endl<<endl;;
	
	cout<<"\\hline"<<endl;
	for(iter=pip_secondaries.begin(); iter!=pip_secondaries.end(); iter++){
		string lab = iter->first;
		double val = iter->second;
		
		// convert label to TeX
		TeXize(lab);
		
		char tmp[256];
		sprintf(tmp, "%2.1f", 100.0*val/tot_pip_secondaries);
		string percent(tmp);
	
		sprintf(tmp, "%d", val);
		string valstr(tmp);
		
		cout<<lab<<" & "
		    <<valstr<<" & "
			 <<percent<<"\\\% \\\\"
			 <<endl;
	}
	cout<<"\\hline"<<endl;
	
	cout<<endl<<endl;;
	
	cout<<"\\hline"<<endl;
	for(iter=photon.begin(); iter!=photon.end(); iter++){
		string lab = iter->first;
		double val = iter->second;
		
		// convert label to TeX
		TeXize(lab);
		
		char tmp[256];
		sprintf(tmp, "%2.1f", 100.0*val/tot_photon);
		string percent(tmp);
	
		sprintf(tmp, "%d", val);
		string valstr(tmp);
		
		cout<<lab<<" & "
		    <<valstr<<" & "
			 <<percent<<"\\\% \\\\"
			 <<endl;
	}
	cout<<"\\hline"<<endl;
	
	cout<<endl<<endl;;
	
	cout<<"\\hline"<<endl;
	for(iter=photon_secondaries.begin(); iter!=photon_secondaries.end(); iter++){
		string lab = iter->first;
		double val = iter->second;
		
		// convert label to TeX
		TeXize(lab);
		
		char tmp[256];
		sprintf(tmp, "%2.1f", 100.0*val/tot_photon_secondaries);
		string percent(tmp);
	
		sprintf(tmp, "%d", val);
		string valstr(tmp);
		
		cout<<lab<<" & "
		    <<valstr<<" & "
			 <<percent<<"\\\% \\\\"
			 <<endl;
	}
	cout<<"\\hline"<<endl;

	cout<<endl;
}

//----------------
// TeXize
//----------------
void TeXize(string &lab)
{
	size_t pos = lab.find("<");
	if(pos!=string::npos)lab.replace(pos,1,"$<$");
	size_t pos = lab.find(">=");
	if(pos!=string::npos)lab.replace(pos,2,"$\\\geq$");
	size_t pos = lab.find("e+");
	if(pos!=string::npos)lab.replace(pos,2,"$e^{+}$");
	size_t pos = lab.find("e-");
	if(pos!=string::npos)lab.replace(pos,2,"$e^{-}$");
	size_t pos = lab.find("pi+");
	if(pos!=string::npos)lab.replace(pos,3,"$\\pi^{+}$");
	size_t pos = lab.find("gamma");
	if(pos!=string::npos)lab.replace(pos,5,"$\\gamma$");
	size_t pos = lab.find("&&");
	if(pos!=string::npos)lab.replace(pos,2,"AND");
	size_t pos = lab.find("==");
	if(pos!=string::npos)lab.replace(pos,2,"=");
}

