
#include "StandardLabels.C"

void secondary_origin_r(void)
{

	TFile *f = new TFile("hd_root.root");
	TTree *reconPhoton = (TTree*)gROOT->FindObject("reconPhoton");
	
	TCanvas *c1 = new TCanvas("c1");
	c1->SetTicks();
	c1->SetGridy();
	c1->SetLogy();
	
	TH1D *primary = new TH1D("primary", "Secondary shower origin", 200, 0.0, 110.0);
	primary->SetXTitle("r (cm)");
	primary->SetStats(0);
	primary->SetLineWidth(2);
	primary->SetFillStyle(3002);
	
	TH1D *secondary = (TH1D*)primary->Clone("secondary");

	reconPhoton->Project("primary", "R.pos_origin.Perp()", "idist_to_thrown==0");
	reconPhoton->Project("secondary", "R.pos_origin.Perp()", "idist_to_thrown>0");

	primary->SetLineColor(kBlue);
	secondary->SetLineColor(kRed);
	primary->SetFillColor(kBlue);
	secondary->SetFillColor(kRed);
	
	primary->SetFillStyle(3001);

	primary->Draw();
	secondary->Draw("same");
	
	TLegend *leg = new TLegend(0.119, 0.722, 0.356, 0.881);
	leg->SetFillColor(kWhite);
	leg->AddEntry(primary, "primary shower");
	leg->AddEntry(secondary, "secondary shower");
	leg->Draw();
	
	// Draw detector boundaries
	// Solenoid
	double r1 = 94.5;
	double r2 = 110.0;
	TLine *l = new TLine(r1, -0.5, r1, 1.5E5);
	l->SetLineStyle(4);
	l->SetLineWidth(3);
	l->Draw();
	TArrow *a = new TArrow(r1, 6.0E4, r2, 6.0E4, 0.015, "<->");
	a->Draw();
	TLatex *lab = new TLatex((r1+r2)/2.0, 6.1E4, "Solenoid");
	lab->SetTextAlign(21);
	lab->SetTextSize(0.03);
	lab->Draw();
	
	// Draw detector boundaries
	// BCAL
	double r1 = 64.3;
	double r2 = 86.17;
	TLine *l = new TLine(r1, -0.5, r1, 1.5E5);
	l->SetLineStyle(2);
	l->SetLineWidth(3);
	l->Draw();
	l = new TLine(*l);
	l->SetX1(r2); l->SetX2(r2);
	l->Draw();
	TArrow *a = new TArrow(r1, 6.0E4, r2, 6.0E4, 0.02, "<->");
	a->Draw();
	TLatex *lab = new TLatex((r1+r2)/2.0, 6.1E4, "BCAL");
	lab->SetTextAlign(21);
	lab->SetTextSize(0.03);
	lab->Draw();

	// FDC supports
	double r1 = 49.5;
	double r2 = 59.0;
	TLine *l = new TLine(r1, -0.5, r1, 1.5E5);
	l->SetLineStyle(3);
	l->SetLineWidth(3);
	l->Draw();
	l = new TLine(*l);
	l->SetX1(r2); l->SetX2(r2);
	l->Draw();
	TArrow *a = new TArrow(r1, 6.0E4, r2, 6.0E4, 0.01, "<->");
	a->Draw();
	TLatex *lab = new TLatex((r1+r2)/2.0, 6.5E4, "FDC");
	lab->SetTextAlign(21);
	lab->SetTextSize(0.03);
	lab->Draw();
	TLatex *lab = new TLatex((r1+r2)/2.0, 5.5E4, "frames");
	lab->SetTextAlign(23);
	lab->SetTextSize(0.03);
	lab->Draw();
	
	// CDC outer shell
	double r = 56.1;
	TArrow *a = new TArrow(r, 1.1E3, r, 1.5E3, 0.01, "<-");
	a->Draw();
	TLatex *lab = new TLatex(r, 1.7E3, "CDC outer shell");
	lab->SetTextAlign(12);
	lab->SetTextSize(0.02);
	lab->SetTextAngle(90.0);
	lab->Draw();

	// FDC outer shell
	double r = 51.9;
	TArrow *a = new TArrow(r, 8.0E2, r, 1.5E3, 0.01, "<-");
	a->Draw();
	TLatex *lab = new TLatex(r, 1.7E3, "FDC outer shell");
	lab->SetTextAlign(12);
	lab->SetTextSize(0.02);
	lab->SetTextAngle(90.0);
	lab->Draw();
	
	StandardLabels1D(primary,"Single #gamma events  1GeV/c  14^{o}#leq60^{o}", "100k events", "All Events");

	c1->SaveAs("secondary_origin_r.png");
	c1->SaveAs("secondary_origin_r.pdf");
}

