
#include "GlueX_boundaries.C"
#include "StandardLabels.C"

void ptype_closest(void)
{
	
	
	TFile *f = new TFile("hd_root.root");
	TTree *reconPhoton = (TTree*)gROOT->FindObject("reconPhoton");
	
	TCanvas *c1 = new TCanvas("c1");
	c1->SetTicks();
	c1->SetGridy();
	
	TH1D *h = new TH1D("h", "Particle initiating secondary showers", 31, -0.25, 15.25);
	h->SetStats(0);
	TAxis *xaxis = h->GetXaxis();
	
	// Set particle names as axis labels. In order for ROOT to display the
	// whole range, we must set a label for each bin. To make it prettier,
	// we have empty bins in between.
	for(int bin=1 ; bin<=h->GetNbinsX(); bin++){
		const char *lab = " ";
		if(((bin+1)%2)==0 && bin>=3){
			int pid = (bin-1)/2;
			switch(pid){
				case 1: lab="#gamma";   break;
				case 2: lab="e^{+}";   break;
				case 3: lab="e^{-}";   break;
				case 4: lab="#nu";   break;
				case 5: lab="#mu^{+}";   break;
				case 6: lab="#mu^{-}";   break;
				case 7: lab="#pi^{o}";   break;
				case 8: lab="#pi^{+}";   break;
				case 9: lab="#pi^{-}";   break;
				case 10: lab="K^{o}_{L}";   break;
				case 11: lab="K^{+}";   break;
				case 12: lab="K^{-}";   break;
				case 13: lab="neutron";   break;
				case 14: lab="proton";   break;
			}
		}

		xaxis->SetBinLabel(bin, lab);
	}

	reconPhoton->Project("h", "ptype_closest", "Nrecon>1 && idist_to_thrown>0");

	h->SetFillColor(kBlue);
	h->Draw("B");
	
	// Draw percentage labels over each bin
	for(int bin=1 ; bin<=h->GetNbinsX(); bin++){
		double y = h->GetBinContent(bin);
		double percent = 100.0*y/h->Integral();
		if(percent<0.1)continue;
		char str[256];
		sprintf(str, "%2.1f%%", percent);
		TLatex *l = new TLatex(xaxis->GetBinCenter(bin), y*1.0+0.01*h->GetMaximum(), str);
		l->SetTextAlign(21);
		l->SetTextSize(0.022);
		l->Draw();
	}	
	
	StandardLabels1D(h,"Single #pi^{+} events  1GeV/c  14^{o}#leq60^{o}", "100k events", "All particles");

	c1->SaveAs("ptype_closest.png");
	c1->SaveAs("ptype_closest.pdf");
}

